#  FACT Employment Official Statistics
Official labor statistics about the US and European countries. Data sources are the Bureau of Labor Statistics (BLS) and the Census in the US and EUROSTAT in Europe. They vary in frequency of observation (either annually or quarterly), geographical scope, and industrial details.

---

[![GitLab License](https://img.shields.io/gitlab/license/fact%2Fdata%2FFACT_jobs?gitlab_url=https%3A%2F%2Fgit.nilu.no&style=flat&color=orange)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
[![DOI](https://img.shields.io/badge/DOI-10.17605%2FOSF.IO%2FUK3HJ-blue?style=flat)](https://doi.org/10.17605/OSF.IO/UK3HJ)
[![Data License](https://img.shields.io/badge/data-CC%20BY%204.0-green)](https://creativecommons.org/licenses/by/4.0/legalcode.txt)

---

## Use
1. Through the command line:
```bash
docker pull registry.git.nilu.no/fact/data/fact_jobs:latest
docker run -t -i --name fact\_jobs -e MARIADB\_DATABASE=FACT_jobs -e MYSQL\_ROOT\_PASSWORD=devops -p 3308:3306 -d registry.git.nilu.no/fact/data/fact\_jobs:0.1
```
2. Through a docker-compose file:
```yaml
version: '3.8'

services:
  fact_jobs:
    image: registry.git.nilu.no/fact/data/fact_jobs:latest
    container_name: fact_jobs
    environment:
      MARIADB_DATABASE: FACT_jobs
      MYSQL_ROOT_PASSWORD: devops
    ports:
      - "3308:3306"
    restart: unless-stopped
```
which could be executed with `docker-compose up fact_jobs -d`.

The container makes available a MariaDB instance with the full database on employment. It is reachable on port 3308 of the localhost and the root password is 'devops'.

---
## Specifications
### Data size
```
+--------+-----------+----------+
| Table  | Size (MB) | Rows (#) |
+--------+-----------+----------+
| LFS    |      2.35 |    43278 |
| LODES8 |   2323.16 | 41592806 |
| QCEW   |   6916.19 | 59684807 |
| REA    |     22.52 |   418223 |
| SBS    |      1.54 |    25938 |
+--------+-----------+----------+
```
### Data structure
![Database tables](FACT_jobs_db.png "Title")
### Data fields
#### LODES8 - LEHD Origin-Destination Employment Statistics, the U.S. Census
Data refers to **jobs**.
| Column | Description |
|---|---|
|GeoID| FIPS block id, 15 chars: STATE+COUNTY+TRACT+BLOCK |
|Year| 2002-2021|
|CNS01 | Number of jobs in NAICS sector 11 (Agriculture, Forestry, Fishing and Hunting)|
| CNS02 | Number of jobs in NAICS sector 21 (Mining, Quarrying, and Oil and Gas Extraction)|
| CNS03 | Number of jobs in NAICS sector 22 (Utilities)|
| CNS04 | Number of jobs in NAICS sector 23 (Construction)|
| CNS05 | Number of jobs in NAICS sector 31-33 (Manufacturing)|
| CNS06 | Number of jobs in NAICS sector 42 (Wholesale Trade)|
| CNS07 | Number of jobs in NAICS sector 44-45 (Retail Trade)|
| CNS08 | Number of jobs in NAICS sector 48-49 (Transportation and Warehousing)|
| CNS09 | Number of jobs in NAICS sector 51 (Information)|
| CNS10 | Number of jobs in NAICS sector 52 (Finance and Insurance)|
| CNS11 | Number of jobs in NAICS sector 53 (Real Estate and Rental and Leasing)|
| CNS12 | Number of jobs in NAICS sector 54 (Professional, Scientific, and Technical Services)|
| CNS13 | Number of jobs in NAICS sector 55 (Management of Companies and Enterprises)|
| CNS14 | Number of jobs in NAICS sector 56 (Administrative and Support and Waste Management and Remediation Services)|
| CNS15 | Number of jobs in NAICS sector 61 (Educational Services)|
| CNS16 | Number of jobs in NAICS sector 62 (Health Care and Social Assistance)|
| CNS17 | Number of jobs in NAICS sector 71 (Arts, Entertainment, and Recreation)|
| CNS18 | Number of jobs in NAICS sector 72 (Accommodation and Food Services)|
| CNS19 | Number of jobs in NAICS sector 81 (Other Services [except Public Administration])|
| CNS20 | Number of jobs in NAICS sector 92 (Public Administration)|

#### QCEW - Quarterly Census of Employment and Wages, the U.S. Bureau of Labor Statistics
| Column | Description |
|---|---|
|GeoID| FIPS: US, STATE, COUNTY |
|Year| 2000-2023|
|Naics| Industry codes|
|Agglvl_code |14 	National, by NAICS Sector; 15 	National, by NAICS 3-digit; 16 	National, by NAICS 4-digit; 17 	National, by NAICS 5-digit; 18 	National, by NAICS 6-digit; 54 	Statewide, NAICS Sector; 55 	Statewide, NAICS 3-digit; 56 	Statewide, NAICS 4-digit; 57 	Statewide, NAICS 5-digit; 58 	Statewide, NAICS 6-digit; 74 	County, NAICS Sector; 75 	County, NAICS 3-digit; 76 	County, NAICS 4-digit; 77 	County, NAICS 5-digit; 78 	County, NAICS 6-digit |
|Q1_establishments| Number of establishments in quarter 1|
|Q1_disclosure| Percentage of establishments with disclosed information in quarter 1|
|Q1_avg_weekly_wage| Average weekly wage in quarter 1|
|Jan_jobs| Number of jobs in January|
|...|...|


#### REA - Regional Economic Accounts, EUROSTAT
Data refers to **employed persons**.
| Column | Description |
|---|---|
|GeoID| NUTS 0 - 3 |
|Year| 1995-2022|
|Nace | Reduced level 1 NACE, Rev. 2|
|EmpTh | Thousands of Employed Persons|

Source: [doi:10.2908/NAMA_10R_3EMPERS](https://doi.org/10.2908/NAMA_10R_3EMPERS)


#### LFS - Labour Force Survey, EUROSTAT
Data refers to people of any sex and any age > 15 years old who are **employed persons**.
| Column | Description |
|---|---|
|GeoID| NUTS 0 - 2 char country code |
|Year| 2008-2023|
|Nace | Level 2 NACE, Rev. 2|
|EmpTh_Q1 | Thousands of Employed Persons in Quarter 1|
|EmpTh_Q2 | Thousands of Employed Persons in Quarter 2|
|EmpTh_Q3 | Thousands of Employed Persons in Quarter 3|
|EmpTh_Q4 | Thousands of Employed Persons in Quarter 4|

Source: [doi:10.2908/LFSQ_EGAN22D](https://doi.org/10.2908/LFSQ_EGAN22D)

#### SBS - Structural Business Statistics, EUROSTAT
Data include only G data source below for now and hence are limited to 2021.
| Column | Description |
|---|---|
|GeoID| NUTS 0 - 2 char country code |
|Year| 2008-2022|
|Nace | Level 4 NACE, Rev. 2|
|Enterprises| Number of enterprises |
|Employment| Persons employed - number |
|LaborCost| Unit labor cost per person employed, thousand euro|

Source: [doi:10.2908/SBS_OVW_ACT](https://doi.org/10.2908/SBS_OVW_ACT)

---
## Notes
Data is selected, downloaded, and reorganized from multiple data sources.
### LODES
The U.S. Census publishes regularly the [Longitudinal Employer-Household Dynamics - LEHD](https://lehd.ces.census.gov/data/) and within that the [LEHD Origin-Destination Employment Statistics - LODES](https://lehd.ces.census.gov/data/lodes/).

The data considered here is the Workplace Area Characteristics (WAC) of LODES8, where the version number indicates the TIGER geographical boundary specification adopted (2020 Census blocks). Details are at https://lehd.ces.census.gov/data/lodes/LODES8/LODESTechDoc8.0.pdf.

The overall period is 2002-2021 but not all states are represented in all periods. All 51 states are available for only the period 2011-2016.

### BLS
BLS data could not be downloaded though API because of limitations on daily number of combination of series and time periods. QCEW data, however, is published also in tabular formats https://www.bls.gov/cew/downloadable-data-files.htm.

Percentage of disclosure refers to number of establishments and is much influenced by the fact that data is reported at different ownership codes and without totals. The more details means less disclosure, of course.
```
+-------------+--------------------------------+
| Agglvl_code | TRUNCATE(AVG(Q1_disclosure),4) |
+-------------+--------------------------------+
| 14          |                         0.9999 |
| 15          |                         0.9990 |
| 16          |                         0.9992 |
| 17          |                         0.9980 |
| 18          |                         0.9975 |
| 54          |                         0.9920 |
| 55          |                         0.9536 |
| 56          |                         0.8972 |
| 57          |                         0.8534 |
| 58          |                         0.7892 |
| 74          |                         0.7723 |
| 75          |                         0.6351 |
| 76          |                         0.5094 |
| 77          |                         0.4270 |
| 78          |                         0.3971 |
+-------------+--------------------------------+
```

### EUROSTAT
#### REA
**A**. *Employment (thousand persons) by NUTS 3 regions (Level 1 NACE)*
https://ec.europa.eu/eurostat/databrowser/product/view/nama_10r_3empers

**B**. *Compensation of employees by NUTS 2 regions (Level 1 NACE)*
https://ec.europa.eu/eurostat/databrowser/product/view/nama_10r_2coe

**C**. *Employment (thousand hours worked) by NUTS 2 regions (Level 1 NACE)*
https://ec.europa.eu/eurostat/databrowser/product/view/nama_10r_2emhrw

#### LFS
**D**. *Employment by sex, age and detailed economic activity (from 2008 onwards, NACE Rev. 2 two digit level) - 1 000*
https://ec.europa.eu/eurostat/databrowser/product/view/lfsq_egan22d

**E**. *Employment by sex, age, economic activity and NUTS 2 regions (NACE Rev. 2 level 1) (1 000)*
https://ec.europa.eu/eurostat/databrowser/product/view/lfst_r_lfe2en2

**SBS**

**F**. *SBS data by NUTS 2 regions and NACE Rev. 2 (from 2008 onwards)*
https://ec.europa.eu/eurostat/databrowser/product/view/sbs_r_nuts06_r2

**G**. *Enterprises by detailed NACE Rev.2 activity and special aggregates (from 2021)*
https://ec.europa.eu/eurostat/databrowser/product/view/sbs_ovw_act

**H**. *SBS historical data 2011-2020 - Country, 4-digits*

Annual detailed enterprise statistics for industry (NACE Rev. 2, B-E)
https://ec.europa.eu/eurostat/databrowser/product/view/sbs_na_ind_r2

Annual detailed enterprise statistics for construction (NACE Rev. 2, F)
https://ec.europa.eu/eurostat/databrowser/product/view/sbs_na_con_r2

Annual detailed enterprise statistics for services (NACE Rev. 2 H-N and S95)
https://ec.europa.eu/eurostat/databrowser/product/view/sbs_na_1a_se_r2

Annual detailed enterprise statistics for trade (NACE Rev. 2 G)
https://ec.europa.eu/eurostat/databrowser/product/view/sbs_na_dt_r2

| Ref.| Vars | NUTS | TIME| NACE | Notes
|---|---|---|---|---|---|
| A | e | 3 | 95/21 annual | 1r | 11 industries
| B | s | 2 |  | 1r | |
| C | e | 2 | 95/21 annual | 1r ||
| D | e | 0 | 08/23 quarterly | 2 ||
| E | e | 2 | 08/22 annual | 1r | 10 industries
| F | e,u,s | 2 | 08/20 annual | 2 (3 G) | no Ag |
| G | e,u,s | 0 | 21 annual | 4 | no Ag |
| H | e,u,s | 0 | 05/20 annual | 4 | no Ag, split in parts |

>Vars: e=employment #; u=units/enterprises; s=salary/wages

Most up-to-date: D

Highest frequency: D

Most industry detail: G, H

Most space detail: A
```
  ^ NUTS
  |
3 |       A
  |
2 |     B,C,E    F
  |
1 |
  |
0 |              D             G,H
  |                                   NACE
  ----------------------------------->
         1r      2      3       4
```
We select D as main reference, and aim at expanding to G,H (for NACE) and to A (for NUTS).
We not consider further B,C,E, and possibly F, which in contrast could be used for validation.

Note that only F, G, H have info on units/enterprises and salaries.

```
  ^ NUTS
  |
3 |   REA(A)
  |
2 |            
  |
1 |
  |
0 |            LFS(D)        SBS(G,H)
  |                                   NACE
  ----------------------------------->
         1r      2      3       4
REA:  Regional Economic Accounts
SBS:  Structural Business Statistics
LFS:  Labour Force Survey
```


---
## Author
Riccardo Boero - ribo@nilu.no

## Licenses
All the code and the resulting docker images in this project are subject to:
- [GNU General Public License v2](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).

The data is released under: 
- [CC BY 4.0](https://creativecommons.org/licenses/by/4.0/) license.

The input data is subject to:
- [Eurostat data](https://ec.europa.eu/eurostat/about-us/policies/copyright)
- [BLS Terms of Service](https://www.bls.gov/developers/termsOfService.htm)
- [Census Terms of Service](https://www.census.gov/data/developers/about/terms-of-service.html) This product uses the Census Bureau Data API but is not endorsed or certified by the Census Bureau.

## Citation

- Boero, Riccardo. 2024. “FACT Data: Employment Official Statistics.” OSF. [doi:10.17605/OSF.IO/UK3HJ](https://doi.org/10.17605/OSF.IO/UK3HJ). 

Part of the Fine scAle eConomic daTa - FACT project:
- Boero, Riccardo. 2024. “Fine scAle eConomic daTa - FACT.” OSF. [doi:10.17605/OSF.IO/PV4ZW](https://doi.org/10.17605/OSF.IO/PV4ZW). 